Index: /trunk/src/VBox/ValidationKit/tests/additions/tdAddGuestCtrl.py
===================================================================
--- /trunk/src/VBox/ValidationKit/tests/additions/tdAddGuestCtrl.py	(revision 105887)
+++ /trunk/src/VBox/ValidationKit/tests/additions/tdAddGuestCtrl.py	(revision 105888)
@@ -1730,6 +1730,8 @@
         fEnableVerboseLogging = False;
 
-        # On Windows guests we always can enable verbose logging. NT4 and W2K doesn't have reg.exe nor (at least NT4) sc.exe.
-        if oTestVm.isWindows() and oTestVm.sKind not in ('WindowsNT4', 'Windows2000',):
+        # On Windows and Linux guests we always can enable verbose logging.
+        # NT4 and W2K doesn't have reg.exe nor (at least NT4) sc.exe.
+        if (oTestVm.isWindows() and oTestVm.sKind not in ('WindowsNT4', 'Windows2000',)) \
+        or oTestVm.isLinux():
             fEnableVerboseLogging = True;
 
